Uses locking algorithm with S3 to enforce single User Function execution when there are multiple predecessors Checking the flag to find any other nodes are seeking for the lock.
faasr_anyone_else_interested(faasr, target_s3, flag_path, flag_name)a logical value if there are other nodes
list with parsed and validated Payload
the name of target server
the string value of the path for the flag
the string value of the name of the flag