Learn R Programming

FaaSr (version 1.4.4)

faasr_arrow_s3_bucket: faasr_arrow_s3_bucket

Description

`test` Uses "arrow" library to set up the configurations with given json file and provide the object to the users

Value

s3 representing object for "arrow"

Arguments

server_name

for string, default value is faasr$DefaultDataStore

faasr_config

optional configuration to use instead of global .faasr

Examples

Run this code
# this function can be run only inside the container
if (interactive()){
arrow_s3 <- faasr_arrow_s3_bucket()
arrow_s3$ls
}

Run the code above in your browser using DataLab