Learn R Programming

FaaSr (version 1.4.4)

faasr_collect_sys_env: faasr_collect_sys_env

Description

Collect system environment from the R studio If the credential name is property set (Servername + Key name), this function will use Sys.getenv to collect credentials. If there's already credentials in the list, it skips the procedure.

Usage

faasr_collect_sys_env(faasr, cred)

Value

credential list

Arguments

faasr

a list form of the JSON file

cred

a list form of the credentials