powered by
Helper function to delete a file in an S3 bucket
return nothing / delete the file in the bucket
string with name of the S3 bucket to use; must match a name declared in the faasr list
string with the name of the remote folder where the file is to be deleted from
string with the name for the file to be deleted
optional configuration to use instead of global .faasr
# This function can be run only in the container if (interactive()){ faasr_delete_file(remote_file="test.txt") }
Run the code above in your browser using DataLab