Learn R Programming

FaaSr (version 1.4.4)

faasr_delete_log_date: faasr_delete_log_date

Description

deletes all FaaSr logs of a given date This function deleted all FaaSr log files in a given date from the user's S3 FaaSrLog bucket

Usage

faasr_delete_log_date(target_date)

Value

nothing is returned

Arguments

target_date

the date (yyyy-mm-dd) of the log data

Examples

Run this code
if (interactive()){
test <- faasr("test.json", "env")
logs <- test$faasr_delete_log_date('2024-06-05')
}

Run the code above in your browser using DataLab