Learn R Programming

FaaSr (version 1.4.4)

faasr_get_file: faasr_get_file

Description

Helper function to download a file from an S3 bucket to local Action folder

Value

return nothing / delete the file in the bucket

Arguments

server_name

string with name of the S3 bucket to use; must match a name declared in the faasr list

remote_folder

string with the name of the remote folder where the file is to be downloaded from

remote_file

string with the name for the file to be downloaded from the S3 bucket

local_folder

string with the name of the local folder where the file to be downloaded is stored

local_file

string with the name of the local file once downloaded

faasr_config

optional configuration to use instead of global .faasr

Examples

Run this code
# This function can be run only in the container
if (interactive()){
faasr_get_file("remote_folder", "remote_file", "local_folder", "local_file")
}

Run the code above in your browser using DataLab