Learn R Programming

FaaSr (version 1.4.4)

faasr_get_log: faasr_get_log

Description

downloads a FaaSr log file stored in S3 This function downloads a specific FaaSr log file from the user's S3 FaaSrLog bucket to local disk This can be useful in debugging by helping the user retrieve the specific log of a FaaSr run

Usage

faasr_get_log(uuid)

Value

nothing is returned; log is downloaded

Arguments

uuid

the UUID of the log to retrieve

Examples

Run this code
if (interactive()){
test <- faasr("test.json", "env")
logs <- test$faasr_get_log('SOME-UUID')
}


Run the code above in your browser using DataLab