Learn R Programming

FaaSr (version 1.4.4)

faasr_get_log_df: faasr_get_log_df

Description

returns a data frame with FaaSr logs stored in S3 This function queries and aggregates FaaSr log information configured with the user's S3 bucket This can be useful in debugging by helping the user identify and download a particular log

Usage

faasr_get_log_df()

Arguments

Value

this function returns nothing

Examples

Run this code
if (interactive()){
test <- faasr("test.json", "env")
test$faasr_get_log_df()
}

Run the code above in your browser using DataLab