Learn R Programming

FaaSr (version 1.4.4)

faasr_log: faasr_log

Description

Helper function to append to the log file residing in an S3 bucket the name of the S3 server is implicit from the validated JSON payload, key LoggingServer the log file is a concatenation of folder "logs" and file name "faasr_log_" + InvocationID + ".txt"

Value

return nothing / leave the log to the bucket

Arguments

faasr

list with parsed and validated Payload

log_message

string message to be appended to the log

Examples

Run this code
# This function can be run only in the container
if (interactive()){
log_message <- "test message"
faasr_log(log_message)
}

Run the code above in your browser using DataLab