Learn R Programming

FaaSr (version 1.4.4)

faasr_predecessors_list: faasr_predecessors_list

Description

Get the predecessors list, by using the graph from faasr_check_workflow

Usage

faasr_predecessors_list(faasr, graph)

Value

a list of "function:predecessors" pairs.

Arguments

faasr

list with parsed and validated Payload

graph

graph constructed by the depth first search in faasr_check_workflow_cycle