Learn R Programming

FaaSr (version 1.4.4)

faasr_put_file: faasr_put_file

Description

Helper function to upload a file from a local Action folder to an S3 bucket

Value

return nothing / put the file into the bucket

Arguments

server_name

string with name of the S3 bucket to use; must match a name declared in the faasr list

local_folder

string with the name of the local folder where the file to be uploaded resides

local_file

string with the name of the local file to be uploaded

remote_folder

string with the name of the remote folder where the file is to be uploaded to

remote_file

string with the name for the file once uploaded to the S3 bucket

faasr_config

optional configuration to use instead of global .faasr

Examples

Run this code
# This function can be run only in the container
if (interactive()){
faasr_put_file("local_folder", "local_file", "remote_folder", "remote_file")
}

Run the code above in your browser using DataLab