Learn R Programming

FaaSr (version 1.4.4)

faasr_rank: faasr_rank

Description

Helper function to let users identify the rank and max rank in the function This function is used by users in the container.

Usage

faasr_rank()

Arguments

Value

return a list of Rank & MaxRank

Examples

Run this code
# This function can be run only in the container
if (interactive()){
rank_info <- faasr_rank()
MaxRank <- rank_info$MaxRank 
Rank <- rank_info$Rank
}

Run the code above in your browser using DataLab