Learn R Programming

FaaSr (version 1.4.4)

faasr_register_workflow_github_repo_lists: faasr_register_workflow_github_repo_lists

Description

Parse the faasr and get the list of function:repository Find actions which is using "Github Actions" return value's key is action and value is server name.

Usage

faasr_register_workflow_github_repo_lists(faasr)

Value

a list of "action:server name" pairs.

Arguments

faasr

a list form of the JSON file