faasr_register_workflow_openwhisk_action_lists: faasr_register_workflow_openwhisk_action_lists
Description
Parse the faasr and get the list of function:server
Find actions which is using "OpenWhisk"
return value's key is action and value is server name.
Usage
faasr_register_workflow_openwhisk_action_lists(faasr)
Value
an list of "action name: server name" pairs
Arguments
- faasr
a list form of the JSON file