powered by
Uses locking algorithm with S3 to enforce single User Function execution when there are multiple predecessors Release the lock by deleting the lock file in the bucket
faasr_release(faasr)
list with parsed and validated Payload