powered by
`test` Uses "arrow" library to set up the configurations with given json file and provide the object to the users
s3 representing object for "arrow"
for string, default value is faasr$DefaultDataStore
optional configuration to use instead of global .faasr
# this function can be run only inside the container if (interactive()){ arrow_s3 <- faasr_arrow_s3_bucket() arrow_s3$ls }
Run the code above in your browser using DataLab