powered by
deletes all FaaSr logs of a given date This function deleted all FaaSr log files in a given date from the user's S3 FaaSrLog bucket
faasr_delete_log_date(target_date)
nothing is returned
the date (yyyy-mm-dd) of the log data
if (interactive()){ test <- faasr("test.json", "env") logs <- test$faasr_delete_log_date('2024-06-05') }
Run the code above in your browser using DataLab