powered by
Helper function to download a file from an S3 bucket to local Action folder
return nothing / delete the file in the bucket
string with name of the S3 bucket to use; must match a name declared in the faasr list
string with the name of the remote folder where the file is to be downloaded from
string with the name for the file to be downloaded from the S3 bucket
string with the name of the local folder where the file to be downloaded is stored
string with the name of the local file once downloaded
optional configuration to use instead of global .faasr
# This function can be run only in the container if (interactive()){ faasr_get_file("remote_folder", "remote_file", "local_folder", "local_file") }
Run the code above in your browser using DataLab