powered by
downloads a FaaSr log file stored in S3 This function downloads a specific FaaSr log file from the user's S3 FaaSrLog bucket to local disk This can be useful in debugging by helping the user retrieve the specific log of a FaaSr run
faasr_get_log(uuid)
nothing is returned; log is downloaded
the UUID of the log to retrieve
if (interactive()){ test <- faasr("test.json", "env") logs <- test$faasr_get_log('SOME-UUID') }
Run the code above in your browser using DataLab