Helper function to append to the log file residing in an S3 bucket
the name of the S3 server is implicit from the validated JSON payload, key LoggingServer
the log file is a concatenation of folder "logs" and file name "faasr_log_" + InvocationID + ".txt"