powered by
Helper function to upload a file from a local Action folder to an S3 bucket
return nothing / put the file into the bucket
string with name of the S3 bucket to use; must match a name declared in the faasr list
string with the name of the local folder where the file to be uploaded resides
string with the name of the local file to be uploaded
string with the name of the remote folder where the file is to be uploaded to
string with the name for the file once uploaded to the S3 bucket
optional configuration to use instead of global .faasr
# This function can be run only in the container if (interactive()){ faasr_put_file("local_folder", "local_file", "remote_folder", "remote_file") }
Run the code above in your browser using DataLab