powered by
Helper function to let users identify the rank and max rank in the function This function is used by users in the container.
faasr_rank()
return a list of Rank & MaxRank
# This function can be run only in the container if (interactive()){ rank_info <- faasr_rank() MaxRank <- rank_info$MaxRank Rank <- rank_info$Rank }
Run the code above in your browser using DataLab